# API Reference

This section provides a concise summary of all public APIs, designed for quick lookups when you know what you're looking for but need to check specific parameters or method signatures.

---

## 📖 Table of Contents

* [1. Glossary (Definitions)](./glossary.md)
* [2. Decorators Reference](./decorators.md)
* [3. `PicoContainer` API](./container.md)
* [4. Protocols (`MethodInterceptor`, etc.)](./protocols.md)
* [5. `EventBus` API](./event_bus.md)
